@@ -7,7 +7,7 @@ package accounts
 import (
 	"encoding/base64"
 	"errors"
-	"io/ioutil"
+	"fmt"
 	"os"
 	"path"
 	"path/filepath"
@@ -50,6 +50,7 @@ const (
 	confKeyGreeterBackground  = "GreeterBackground"
 	confKeyHistoryLayout      = "HistoryLayout"
 	confKeyUse24HourFormat    = "Use24HourFormat"
+	confKeyWechatAuthEnabled  = "WechatAuthEnabled"
 	confKeyUUID               = "UUID"
 	confKeyWorkspace          = "Workspace"
 	confKeyWeekdayFormat      = "WeekdayFormat"
@@ -60,19 +61,20 @@ const (
 	confKeyWeekBegins         = "WeekBegins"
 	confKeyPasswordHint       = "PasswordHint"
 
-	defaultUse24HourFormat = true
-	defaultWeekdayFormat   = 0
-	defaultShortDateFormat = 3
-	defaultLongDateFormat  = 1
-	defaultShortTimeFormat = 0
-	defaultLongTimeFormat  = 0
-	defaultWeekBegins      = 0
-	defaultWorkspace       = 1
+	defaultWechatAuthEnabled = false
+	defaultUse24HourFormat   = true
+	defaultWeekdayFormat     = 0
+	defaultShortDateFormat   = 3
+	defaultLongDateFormat    = 1
+	defaultShortTimeFormat   = 0
+	defaultLongTimeFormat    = 0
+	defaultWeekBegins        = 0
+	defaultWorkspace         = 1
 )
 
 const (
 	deepinThemePath         = "/usr/share/deepin-themes/"
-	defaultTheme            = "bloom"
+	defaultTheme            = "nirvana"
 	themeFile               = "index.theme"
 	themeGroupDefault       = "DefaultTheme"
 	themeGroupDark          = "DarkTheme"
@@ -146,6 +148,10 @@ type User struct {
 	Locked bool
 	// 是否允许此用户自动登录
 	AutomaticLogin bool
+
+	// 是否快速登录
+	QuickLogin bool
+
 	// 当前工作区
 	Workspace int32
 
@@ -163,8 +169,9 @@ type User struct {
 	// dbusutil-gen: equal=nil
 	HistoryLayout []string
 
-	configLocker   sync.Mutex
-	customIconList []string
+	WechatAuthEnabled bool
+	configLocker      sync.Mutex
+	customIconList    []string
 }
 
 func NewUser(userPath string, service *dbusutil.Service, ignoreErr bool) (*User, error) {
@@ -192,6 +199,7 @@ func NewUser(userPath string, service *dbusutil.Service, ignoreErr bool) (*User,
 		HomeDir:            userInfo.Home,
 		Shell:              userInfo.Shell,
 		AutomaticLogin:     users.IsAutoLoginUser(userInfo.Name),
+		QuickLogin:         users.IsQuickLoginUser(userInfo.Name),
 		NoPasswdLogin:      users.CanNoPasswdLogin(userInfo.Name),
 		Locked:             shadowInfo.Status == users.PasswordStatusLocked,
 		PasswordStatus:     shadowInfo.Status,
@@ -207,7 +215,7 @@ func NewUser(userPath string, service *dbusutil.Service, ignoreErr bool) (*User,
 	return u, nil
 }
 
-func NewUdcpUser(usrId uint32, service *dbusutil.Service, groups []string) (*User, error) {
+func NewDomainUser(usrId uint32, service *dbusutil.Service, groups []string) (*User, error) {
 	var err error
 	if users.ExistPwUid(usrId) != 0 {
 		return nil, errors.New("no such user id")
@@ -224,6 +232,7 @@ func NewUdcpUser(usrId uint32, service *dbusutil.Service, groups []string) (*Use
 		HomeDir:            users.GetPwDir(usrId),
 		Shell:              users.GetPwShell(usrId),
 		AutomaticLogin:     users.IsAutoLoginUser(userName),
+		QuickLogin:         users.IsQuickLoginUser(userName),
 		NoPasswdLogin:      users.CanNoPasswdLogin(userName),
 		Locked:             false,
 		PasswordStatus:     users.PasswordStatusUsable,
@@ -231,6 +240,7 @@ func NewUdcpUser(usrId uint32, service *dbusutil.Service, groups []string) (*Use
 		PasswordLastChange: 18737,
 	}
 
+	u.AccountType = users.UserTypeDomain
 	u.Groups = groups
 
 	// 解析对应域管用户是否有添加到sudo组里面，有为管理员用户，否则为标准用户
@@ -445,6 +455,13 @@ func (u *User) updatePropAutomaticLogin() {
 	u.PropsMu.Unlock()
 }
 
+func (u *User) updatePropQuickLogin() {
+	newVal := users.IsQuickLoginUser(u.UserName)
+	u.PropsMu.Lock()
+	u.setPropQuickLogin(newVal)
+	u.PropsMu.Unlock()
+}
+
 func (u *User) updatePropsPasswd(uInfo *users.UserInfo) {
 	var userNameChanged bool
 	var oldUserName string
@@ -555,11 +572,6 @@ func (u *User) checkAuth(sender dbus.Sender, selfPass bool, actionId string) err
 		return nil
 	}
 
-	if !isSelf {
-		// 鉴权非本用户的数据一律需要鉴权管理员
-		actionId = polkitActionUserAdministration
-	}
-
 	if actionId == "" {
 		if isSelf {
 			actionId = polkitActionChangeOwnData
@@ -582,6 +594,17 @@ func (u *User) checkAuthAutoLogin(sender dbus.Sender, enabled bool) error {
 	return u.checkAuth(sender, false, actionId)
 }
 
+func (u *User) checkAuthQuickLogin(sender dbus.Sender, enabled bool) error {
+	var actionId string
+	if enabled {
+		actionId = polkitActionEnableQuickLogin
+	} else {
+		actionId = polkitActionDisableQuickLogin
+	}
+
+	return u.checkAuth(sender, false, actionId)
+}
+
 func (u *User) checkAuthNoPasswdLogin(sender dbus.Sender, enabled bool) error {
 	var actionId string
 	if enabled {
@@ -683,7 +706,7 @@ func scaleUserIcon(file string) (string, bool, error) {
 
 // return temp file path and error
 func getTempFile() (string, error) {
-	tmpfile, err := ioutil.TempFile("", "dde-daemon-accounts")
+	tmpfile, err := os.CreateTemp("", "dde-daemon-accounts")
 	if err != nil {
 		return "", err
 	}
@@ -715,7 +738,7 @@ func getUserSession(homeDir string) string {
 }
 
 func getSessionList() []string {
-	fileInfoList, err := ioutil.ReadDir("/usr/share/xsessions")
+	fileInfoList, err := os.ReadDir("/usr/share/xsessions")
 	if err != nil {
 		return nil
 	}
@@ -877,6 +900,12 @@ func loadUserConfigInfo(u *User) {
 		isSave = true
 	}
 
+	u.WechatAuthEnabled, err = kf.GetBoolean(confGroupUser, confKeyWechatAuthEnabled)
+	if err != nil {
+		u.WechatAuthEnabled = defaultWechatAuthEnabled
+		isSave = true
+	}
+
 	u.WeekdayFormat, err = kf.GetInteger(confGroupUser, confKeyWeekdayFormat)
 	if err != nil {
 		u.WeekdayFormat = defaultWeekdayFormat
@@ -947,3 +976,68 @@ func loadUserConfigInfo(u *User) {
 
 	u.checkLeftSpace()
 }
+
+func (u *User) setAutomaticLogin(enabled bool) *dbus.Error {
+	u.PropsMu.Lock()
+	defer u.PropsMu.Unlock()
+
+	if u.Locked {
+		return dbusutil.ToError(fmt.Errorf("user %s has been locked", u.UserName))
+	}
+
+	if u.AutomaticLogin == enabled {
+		return nil
+	}
+
+	var name = u.UserName
+	if !enabled {
+		name = ""
+	}
+
+	session := u.XSession
+	if session == "" {
+		session = getUserSession(u.HomeDir)
+	}
+	if err := users.SetAutoLoginUser(name, session); err != nil {
+		logger.Warning("DoAction: set auto login failed:", err)
+		return dbusutil.ToError(err)
+	}
+
+	u.AutomaticLogin = enabled
+	_ = u.emitPropChangedAutomaticLogin(enabled)
+	return nil
+}
+
+// 设置用户是否快速登录
+func (u *User) setQuickLogin(enabled bool) *dbus.Error {
+	u.PropsMu.Lock()
+	defer u.PropsMu.Unlock()
+
+	if u.Locked {
+		return dbusutil.ToError(fmt.Errorf("user %s has been locked", u.UserName))
+	}
+
+	if u.QuickLogin == enabled {
+		return nil
+	}
+
+	// 先打开总开关
+	if enabled {
+		accountsManager := getAccountsManager()
+		if accountsManager == nil {
+			return dbusutil.ToError(errors.New("get accounts manager failed"))
+		}
+		err := accountsManager.setDConfigQuickLoginEnabled(true)
+		if err != nil {
+			return dbusutil.ToError(fmt.Errorf("set greeter dconfig enableQuickLogin failed: %v", err))
+		}
+	}
+
+	err := users.SetQuickLogin(u.UserName, enabled)
+	if err != nil {
+		return dbusutil.ToError(err)
+	}
+
+	u.setPropQuickLogin(enabled)
+	return nil
+}
