@@ -27,15 +27,32 @@ import (
 	login1 "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.login1"
 	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/procfs"
+	dutils "github.com/linuxdeepin/go-lib/utils"
 )
 
 // 这里出于安全考虑, 一方面为了防止被 debug, 另一方面为了防止环境变量被篡改,
 // 所以需要将重置密码的对话框 (文件位于 resetPwdDialogPath)
 // 以一个特殊的用户的身份运行, 这个用户只做运行对话框这一件事情.
 
-const pwdChangerUserName = "nobody"                                            //#nosec G101
+var pwdChangerUserName = "deepin-password-admin"                               //#nosec G101
 const resetPwdDialogPath = "/usr/lib/dde-control-center/reset-password-dialog" //#nosec G101
 
+func init() {
+	fileInfo, err := os.Stat(resetPwdDialogPath)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	stat := fileInfo.Sys().(*syscall.Stat_t)
+	user, err := user.LookupId(fmt.Sprintf("%d", stat.Uid))
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+	pwdChangerUserName = user.Username
+}
+
 // copy from golang 1.17, comment out some code because of unexported member
 //
 // String returns a human-readable description of c.
@@ -80,6 +97,24 @@ func newCaller(service *dbusutil.Service, sender dbus.Sender) (ret *caller, err
 	}
 
 	proc := procfs.Process(pid)
+	login1Manager := login1.NewManager(service.Conn())
+	sessionPath, err := login1Manager.GetSessionByPID(0, pid)
+	if err != nil {
+		err = fmt.Errorf("fail to get sender session path: %v", err)
+		return
+	}
+
+	session, err := login1.NewSession(service.Conn(), sessionPath)
+	if err != nil {
+		err = fmt.Errorf("fail to create session object proxy: %v", err)
+		return
+	}
+
+	display, err := session.Display().Get(0)
+	if err != nil {
+		err = fmt.Errorf("fail to get sender display: %v", err)
+		return
+	}
 
 	exe, err := proc.Exe()
 	if err != nil {
@@ -127,36 +162,6 @@ func newCaller(service *dbusutil.Service, sender dbus.Sender) (ret *caller, err
 		return
 	}
 
-	login1Manager := login1.NewManager(service.Conn())
-	userObjectPath, err := login1Manager.GetUserByPID(0, pid)
-	if err != nil {
-		err = fmt.Errorf("fail to get sender user path: %v", err)
-		return
-	}
-
-	userDbus, err := login1.NewUser(service.Conn(), userObjectPath)
-	if err != nil {
-		err = fmt.Errorf("new user failed: %v", err)
-		return
-	}
-	sessionInfo, err := userDbus.Display().Get(0)
-	if err != nil {
-		err = fmt.Errorf("fail to get display session info: %v", err)
-		return
-	}
-
-	session, err := login1.NewSession(service.Conn(), sessionInfo.Path)
-	if err != nil {
-		err = fmt.Errorf("fail to create session object proxy: %v", err)
-		return
-	}
-
-	display, err := session.Display().Get(0)
-	if err != nil {
-		err = fmt.Errorf("fail to get sender display: %v", err)
-		return
-	}
-
 	sessionType, err := session.Type().Get(0)
 	if err != nil {
 		err = fmt.Errorf("fail to get sender session type: %v", err)
@@ -424,7 +429,7 @@ func newPwdChangerBase(caller *caller, u *User) (ret *pwdChangerBase, err error)
 
 	cmd := exec.Command(
 		"runuser", "-u", pwdChangerUser.Username, "--",
-		resetPwdDialogPath, "-u", u.UserName, "-a", caller.app,
+		resetPwdDialogPath, "-u", u.UserName, "-f", u.FullName, "-a", caller.app,
 		"--fd", "3") //#nosec G204
 
 	cmd.ExtraFiles = append(cmd.ExtraFiles, writePipe)
@@ -471,11 +476,6 @@ func newPwdChangerBase(caller *caller, u *User) (ret *pwdChangerBase, err error)
 // 对话框的语言和被修改密码的用户的语言设置保持一致
 func newPwdChanger(caller *caller, u *User) (ret pwdChanger, err error) {
 	pcrb, err := newPwdChangerBase(caller, u)
-	if err != nil {
-		logger.Warning(err)
-		return
-	}
-
 	if caller.wayland == "" {
 		ret, err = newPwdChangerX(caller, u, pcrb)
 	} else {
@@ -485,7 +485,7 @@ func newPwdChanger(caller *caller, u *User) (ret pwdChanger, err error) {
 	return
 }
 
-// 此函数负责将来自 caller 的 xauth 凭证发送给 deepin_pwd_changer 用户
+// 此函数负责将来自 caller 的 xauth 凭证发送给 deepin-password-admin 用户
 func newPwdChangerX(caller *caller, u *User, base *pwdChangerBase) (ret *pwdChangerX, err error) {
 	xAuthDir := filepath.Join("/run", "user", fmt.Sprint(base.selfUid))
 	defer func() {
@@ -597,7 +597,7 @@ func runSetfacl(user string, filePath string, isEnable bool) (err error) {
 	return
 }
 
-// 此函数负责临时允许 deepin_pwd_changer 用户访问目标用户的 wayland socket
+// 此函数负责临时允许 deepin-password-admin 用户访问目标用户的 wayland socket
 func newPwdChangerWayland(caller *caller, u *User, base *pwdChangerBase) (ret *pwdChangerWayland, err error) {
 	if err = runSetfacl(pwdChangerUserName, caller.wayland, true); err != nil {
 		return
@@ -686,10 +686,36 @@ func doSetPwdWithUnionID(u *User, sender dbus.Sender, count int) error {
 // 删除用户的 login keyring
 // 由于重置密码时没有输入原密码, 所以恢复 keyring 中的数据是不可能的, 只能直接移除掉.
 func removeLoginKeyring(user *User) (err error) {
-	// FIXME
-	// greeter 界面触发该功能时 user 的 session bus 不存在,
-	// 所以只能简单地直接删除文件, 而不可能通过 keyring 的 daemon 删除密钥环
-	// FIXME login keyring 的位置有没可能变化?
-	err = os.Remove(user.HomeDir + "/.local/share/keyrings/login.keyring")
+	//白盒密钥生效后，就不需要再删除keyring文件
+	dir := path.Join(user.HomeDir, "/.local/share/deepin-keyrings-wb")
+	isUseWhiteboxFunc := func() bool {
+		statusFile := fmt.Sprintf("%s/status", dir)
+		if dutils.IsFileExist(dir) && dutils.IsFileExist(statusFile) {
+			content, err := os.ReadFile(statusFile)
+			if err != nil {
+				return false
+			}
+			if len(content) < 2 {
+				return false
+			}
+			if content[0] == '1' && content[1] == '1' {
+				logger.Info("[removeLoginKeyring] The WhiteBox keyring password has taken effect.")
+				return true
+			}
+		}
+		return false
+	}
+
+	if !isUseWhiteboxFunc() {
+		// FIXME
+		// greeter 界面触发该功能时 user 的 session bus 不存在,
+		// 所以只能简单地直接删除文件, 而不可能通过 keyring 的 daemon 删除密钥环
+		// FIXME login keyring 的位置有没可能变化?
+		loginFile := fmt.Sprintf("%s/login.keyring", dir)
+		if dutils.IsFileExist(loginFile) {
+			err = os.Remove(loginFile)
+		}
+	}
+
 	return
 }
