@@ -7,7 +7,9 @@ package audio
 import (
 	"errors"
 	"fmt"
+	"github.com/linuxdeepin/go-lib/strv"
 	"math"
+	"os"
 	"sort"
 	"strings"
 	"sync"
@@ -37,6 +39,9 @@ const (
 	gsKeyReduceNoise              = "reduce-input-noise"
 	gsKeyOutputAutoSwitchCountMax = "output-auto-switch-count-max"
 
+	gsSchemaControlCenter = "com.deepin.dde.control-center"
+	gsKeyDeviceManager    = "device-manage"
+
 	gsSchemaSoundEffect  = "com.deepin.dde.sound-effect"
 	gsKeyEnabled         = "enabled"
 	gsKeyDisableAutoMute = "disable-auto-mute"
@@ -56,10 +61,15 @@ const (
 	increaseMaxVolume = 1.5
 	normalMaxVolume   = 1.0
 
-	dsgkeyPausePlayer         = "pausePlayer"
-	dsgKeyAutoSwitchPort      = "autoSwitchPort"
-	dsgKeyBluezModeFilterList = "bluezModeFilterList"
-	dsgKeyPortFilterList      = "portFilterList"
+	dsgkeyPausePlayer             = "pausePlayer"
+	dsgKeyAutoSwitchPort          = "autoSwitchPort"
+	dsgKeyBluezModeFilterList     = "bluezModeFilterList"
+	dsgKeyPortFilterList          = "portFilterList"
+	dsgKeyReduceNoise             = "reduceNoise"
+	dsgKeyInputDefaultPriorities  = "inputDefaultPrioritiesByType"
+	dsgKeyOutputDefaultPriorities = "outputDefaultPrioritiesByType"
+	dsgKeyBluezModeDefault        = "bluezModeDefault"
+	dsgKeyMonoEnabled             = "monoEnabled"
 
 	changeIconStart    = "notification-change-start"
 	changeIconFailed   = "notification-change-failed"
@@ -71,6 +81,7 @@ var (
 	defaultOutputVolume          = 0.5
 	defaultHeadphoneOutputVolume = 0.17
 	gMaxUIVolume                 float64
+	defaultReduceNoise           = false
 
 	// 保存 pulaudio ,pipewire 相关的服务
 	pulseaudioServices = []string{pulseaudioService, pulseaudioSocket}
@@ -84,7 +95,7 @@ const (
 	AudioStateChanging = false
 )
 
-//go:generate dbusutil-gen -type Audio,Sink,SinkInput,Source,Meter -import github.com/godbus/dbus/v5 audio.go sink.go sinkinput.go source.go meter.go
+//go:generate dbusutil-gen -type Audio,Sink,SinkInput,Source,Meter -import github.com/godbus/dbus audio.go sink.go sinkinput.go source.go meter.go
 //go:generate dbusutil-gen em -type Audio,Sink,SinkInput,Source,Meter
 
 func objectPathSliceEqual(v1, v2 []dbus.ObjectPath) bool {
@@ -146,6 +157,9 @@ type Audio struct {
 	// 最大音量
 	MaxUIVolume float64 // readonly
 
+	// 单声道设置
+	Mono bool
+
 	headphoneUnplugAutoPause bool
 
 	settings  *gio.Settings
@@ -169,9 +183,9 @@ type Audio struct {
 	cards    CardList
 
 	isSaving     bool
-	sourceIdx    uint32 //used to disable source if select a2dp profile
+	sourceIdx    uint32 // used to disable source if select a2dp profile
 	saverLocker  sync.Mutex
-	enableSource bool //can not enable a2dp Source if card profile is "a2dp"
+	enableSource bool // can not enable a2dp Source if card profile is "a2dp"
 
 	portLocker sync.Mutex
 
@@ -192,8 +206,12 @@ type Audio struct {
 	outputAutoSwitchCount    int
 	outputAutoSwitchCountMax int
 	// 自动端口切换
-	enableAutoSwitchPort bool
-	systemSigLoop        *dbusutil.SignalLoop
+	enableAutoSwitchPort    bool
+	controlCenterGsSettings *gio.Settings
+	// 控制中心-声音-设备管理 是否显示
+	controlCenterDeviceManager gsprop.Bool `prop:"access:rw"`
+
+	systemSigLoop *dbusutil.SignalLoop
 	// 用来进一步断是否需要暂停播放的信息
 	misc uint32
 
@@ -207,6 +225,15 @@ type Audio struct {
 	}
 }
 
+func isStringInSlice(list []string, str string) bool {
+	for _, v := range list {
+		if v == str {
+			return true
+		}
+	}
+	return false
+}
+
 func newAudio(service *dbusutil.Service) *Audio {
 	a := &Audio{
 		service:          service,
@@ -219,6 +246,7 @@ func newAudio(service *dbusutil.Service) *Audio {
 	a.settings = gio.NewSettings(gsSchemaAudio)
 	a.settings.Reset(gsKeyInputVolume)
 	a.settings.Reset(gsKeyOutputVolume)
+	a.settings.Reset(gsKeyHeadphoneOutputVolume)
 	a.IncreaseVolume.Bind(a.settings, gsKeyVolumeIncrease)
 	a.PausePlayer = false
 	a.ReduceNoise = false
@@ -233,6 +261,17 @@ func newAudio(service *dbusutil.Service) *Audio {
 	}
 	gMaxUIVolume = a.MaxUIVolume
 	a.listenGSettingVolumeIncreaseChanged()
+
+	if isStringInSlice(gio.SettingsListSchemas(), gsSchemaControlCenter) {
+		a.controlCenterGsSettings = gio.NewSettings(gsSchemaControlCenter)
+		if isStringInSlice(a.controlCenterGsSettings.ListKeys(), gsKeyDeviceManager) {
+			a.controlCenterDeviceManager.Bind(a.controlCenterGsSettings, gsKeyDeviceManager)
+			a.listenGSettingDeviceManageChanged()
+		}
+	} else {
+		logger.Warning(" [newAudio] gschemas file not exist : /usr/share/glib-2.0/schemas/com.deepin.dde.control-center.gschema.xml")
+	}
+
 	a.sessionSigLoop = dbusutil.NewSignalLoop(service.Conn(), 10)
 	a.syncConfig = dsync.NewConfig("audio", &syncConfig{a: a},
 		a.sessionSigLoop, dbusPath, logger)
@@ -338,13 +377,23 @@ func sendNotify(icon, summary, body string) {
 }
 
 func startAudioServer(service *dbusutil.Service) error {
-	var pulseaudioState string
-	var activeServices, deactiveServices []string
-	audioServers := []string{pulseaudioService, pipewireService}
+	//var pulseaudioState string
+	var activeServices, deactiveServices, needMaskedServices []string
+	audioServers := map[string][]string{
+		pulseaudioService: pulseaudioServices,
+		pipewireService:   pipewireServices,
+	}
+	// 默认音频服务
+	var defaultAudioService = pipewireService
 
+	var hasTreeland = false
+	if os.Getenv("XDG_SESSION_TYPE") == "wayland" {
+		hasTreeland = true
+	}
+
+	// 查询已安装的音频服务状态
 	systemd := systemd1.NewManager(service.Conn())
-
-	for _, server := range audioServers {
+	for server, _ := range audioServers {
 		path, err := systemd.GetUnit(0, server)
 		if err == nil {
 			serverSystemdUnit, err := systemd1.NewUnit(service.Conn(), path)
@@ -359,59 +408,93 @@ func startAudioServer(service *dbusutil.Service) error {
 				return err
 			}
 
-			if server == pulseaudioService {
-				pulseaudioState = state
+			if state == "loaded" {
+				// 可加载的服务列表
+				activeServices = append(activeServices, server)
+			} else if state == "masked" {
+				// 需要disable的服务列表
+				deactiveServices = append(deactiveServices, server)
 			}
-
-			// 做一个特判，pulseaudio 与 pipewire 同时预装，但是没法在装包的时候进行 mask 操作，
-			if state == "loaded" && server == pulseaudioService {
-				activeServices = pulseaudioServices
-				deactiveServices = pipewireServices
-			} else if pulseaudioState == "masked" && server == pipewireService {
-				activeServices = pipewireServices
-				deactiveServices = pulseaudioServices
+		}
+	}
+	logger.Infof("get audio service, actived: %v， deactive: %v", activeServices, deactiveServices)
+	var activeService string
+	var found bool
+	activeService = defaultAudioService
+	needMaskedServices, found = strv.Strv(activeServices).Delete(defaultAudioService)
+	if !found {
+		if hasTreeland {
+			// 如果是treeland环境，只支持pipewire，需要强制切换
+			// 如果不存在，则在masked 服务中查找
+			// 场景：X11环境切换到treeland环境，需要强制切换音频服务为pipewire
+			found = strv.Strv(deactiveServices).Contains(defaultAudioService)
+			if !found {
+				err := fmt.Errorf("not found supported audio services")
+				return err
+			}
+			logger.Warning("ready to unmask service:", audioServers[defaultAudioService])
+		} else {
+			if len(activeServices) > 0 {
+				activeService = activeServices[0]
+			} else {
+				err := fmt.Errorf("no active services found")
+				return err
 			}
-
 		}
 	}
 
-	for _, deactiveService := range deactiveServices {
-		deactiveServicePath, err := systemd.GetUnit(0, deactiveService)
-		if err == nil {
-			if len(deactiveServicePath) != 0 {
-				serverSystemdUnit, err := systemd1.NewUnit(service.Conn(), deactiveServicePath)
-
-				if err != nil {
-					logger.Warning("failed to create service systemd unit", err)
-					return err
-				}
-
-				state, err := serverSystemdUnit.Unit().LoadState().Get(0)
-				if err != nil {
-					logger.Warning("failed to get service active state", err)
-					return err
-				}
-
-				if state != "masked" {
-					_, err := systemd.MaskUnitFiles(0, []string{deactiveService}, false, true)
+	// 将剩余可选的audio服务都mask
+	logger.Info("need to active audio service:", activeService)
+	logger.Info("ready to deactive audio service:", needMaskedServices)
+	for _, server := range needMaskedServices {
+		for _, deactiveService := range audioServers[server] {
+			deactiveServicePath, err := systemd.GetUnit(0, deactiveService)
+			if err == nil {
+				if len(deactiveServicePath) != 0 {
+					serverSystemdUnit, err := systemd1.NewUnit(service.Conn(), deactiveServicePath)
 
 					if err != nil {
-						logger.Warning("Failed to mask unit files", err)
+						logger.Warning("failed to create service systemd unit", err)
+						return err
+					}
+
+					state, err := serverSystemdUnit.Unit().LoadState().Get(0)
+					if err != nil {
+						logger.Warning("failed to get service active state", err)
+						return err
+					}
+
+					if state != "masked" {
+						_, err := systemd.MaskUnitFiles(0, []string{deactiveService}, false, true)
+
+						if err != nil {
+							logger.Warning("Failed to mask unit files", err)
+							return err
+						}
+					}
+
+					// 服务在 mask 之前服务，可能被激活，调用 stop
+					_, err = systemd.StopUnit(0, deactiveService, "replace")
+					if err != nil {
+						logger.Warning("Failed to stop service", err)
 						return err
 					}
 				}
-
-				// 服务在 mask 之前服务，可能被激活，调用 stop
-				_, err = systemd.StopUnit(0, deactiveService, "replace")
-				if err != nil {
-					logger.Warning("Failed to stop service", err)
-					return err
-				}
 			}
 		}
 	}
+	_, err := systemd.UnmaskUnitFiles(0, audioServers[activeService], false)
+	if err != nil {
+		logger.Warning("Failed to unmask unit files", activeServices, "\nError:", err)
+		return err
+	}
+	err = systemd.Reload(0)
+	if err != nil {
+		logger.Warning("Failed to reload unit files. Error:", err)
+		return err
+	}
 
-	for _, activeService := range activeServices {
+	for _, activeService := range audioServers[activeService] {
 		activeServicePath, err := systemd.GetUnit(0, activeService)
 		if err == nil {
 			logger.Debug("ready to start audio server", activeServicePath)
@@ -428,9 +511,10 @@ func startAudioServer(service *dbusutil.Service) error {
 					logger.Warning("failed to get audio server active state", err)
 					return err
 				}
-
+				logger.Info("start audio service", activeService, state)
 				if state != "active" {
 					go func() {
+
 						_, err := serverSystemdUnit.Unit().Start(0, "replace")
 						if err != nil {
 							logger.Warning("failed to start audio server unit:", err)
@@ -454,9 +538,65 @@ func getCtx() (ctx *pulse.Context, err error) {
 	return
 }
 
+const (
+	dndVirtualSinkName        = "deepin_network_displays"
+	fakeCardName              = "VirtualCard"
+	dndVirtualSinkDescription = "NetworkDisplayDevice "
+)
+
+// genFakeCard 用于适配虚拟sink的场景,生成一个假的card
+func (a *Audio) genFakeCard() *Card {
+	sinkList := a.ctx.GetSinkList()
+	for _, sink := range sinkList {
+		if sink.Name == dndVirtualSinkName {
+			port := pulse.CardPortInfo{
+				PortInfo: pulse.PortInfo{
+					Name:        dndVirtualSinkName,
+					Description: dndVirtualSinkDescription,
+					Priority:    0,
+					Available:   2,
+				},
+				Direction: 1,
+				Profiles:  nil,
+			}
+			card := &pulse.Card{
+				Index:         sink.Index,
+				Name:          fakeCardName,
+				OwnerModule:   0,
+				Driver:        "",
+				PropList:      nil,
+				Profiles:      nil,
+				ActiveProfile: pulse.ProfileInfo2{},
+				Ports: pulse.CardPortInfos{
+					port,
+				},
+			}
+
+			fakeCard := &Card{
+				Id:            sink.Card,
+				Name:          card.Name,
+				ActiveProfile: nil,
+				Profiles:      nil,
+				Ports: pulse.CardPortInfos{
+					port,
+				},
+				core: card,
+			}
+			return fakeCard
+		}
+	}
+	return nil
+}
+
 func (a *Audio) refreshCards() {
 	a.cards = newCardList(a.ctx.GetCardList())
-	a.setPropCards(a.cards.string())
+	fakeCard := a.genFakeCard()
+	if fakeCard != nil {
+		a.cards = append(a.cards, fakeCard)
+	}
+	cards := a.cards.string()
+	logger.Infof("cards : %s", cards)
+	a.setPropCards(cards)
 	a.setPropCardsWithoutUnavailable(a.cards.stringWithoutUnavailable())
 }
 
@@ -510,6 +650,16 @@ func (a *Audio) refreshSinks() {
 	sinkInfoList := a.ctx.GetSinkList()
 
 	for _, sinkInfo := range sinkInfoList {
+		if sinkInfo.Name == dndVirtualSinkName {
+			port := pulse.PortInfo{
+				Name:        sinkInfo.Name,
+				Description: dndVirtualSinkDescription,
+				Priority:    0,
+				Available:   2,
+			}
+			sinkInfo.Ports = append(sinkInfo.Ports, port)
+			sinkInfo.ActivePort = port
+		}
 		sinkInfoMap[sinkInfo.Index] = sinkInfo
 		sink, exist := a.sinks[sinkInfo.Index]
 		if exist {
@@ -607,12 +757,13 @@ func (a *Audio) shouldAutoPause() bool {
 		return false
 	}
 	if a.defaultSink == nil {
-		logger.Debug("default sink is nil")
+		logger.Warning("default sink is nil")
 		return false
 	}
 
 	// 云平台无card
 	if a.defaultSink.Card == math.MaxUint32 {
+		logger.Warningf("default sink car is %d", a.defaultSink.Card)
 		return false
 	}
 
@@ -630,11 +781,14 @@ func (a *Audio) shouldAutoPause() bool {
 
 	logger.Debugf("default sink active port: %v %v", port.Name, port.Available)
 	if a.defaultSink.ActivePort.Available == 1 {
+		logger.Warningf("default sink activePort available is %d", a.defaultSink.ActivePort.Available)
 		return false
 	}
 
 	switch DetectPortType(card.core, &port) {
 	case PortTypeBluetooth, PortTypeHeadset, PortTypeLineIO, PortTypeUsb:
+		// 先缓存sink 是否为可插拔信息，防止后面整个card丢失，缺少判断信息。
+		a.defaultSink.pluggable = true
 		return true
 	default:
 		a.defaultSink.pluggable = false
@@ -656,34 +810,117 @@ func (a *Audio) autoPause() {
 
 	if err != nil {
 		logger.Warning(err)
-		pauseAllPlayers()
+		go pauseAllPlayers()
 	} else if card.ActiveProfile.Name == "off" {
-		pauseAllPlayers()
+		go pauseAllPlayers()
 	} else if port.Available == pulse.AvailableTypeNo {
 		// 使用优先级并且未开启自动切换时，先不暂停，后面根据sink信息判断是否需要暂停
+		logger.Debug("wait check priority", port.Priority)
 		a.misc = port.Priority
 		if a.misc == 0 || a.canAutoSwitchPort() {
-			pauseAllPlayers()
+			go pauseAllPlayers()
 		}
 	}
 }
 
+// 尝试获取用户期望的端口
+// 同一张声卡可能存在多个端口，用户也可能切换过端口
+// 通过PriorityManager获取最高优先级对应的卡，然后根据配置获取期望端口
+func (a *Audio) tryGetPreferOutPut() PriorityPort {
+	// 获取PriorityManager获取最高优先级的端口以及对应的声卡
+	firstOutput := GetPriorityManager().Output.GetTheFirstPort()
+	// 获取声卡配置期望的端口
+	preferPort := GetConfigKeeper().GetCardPreferPort(firstOutput.CardName)
+	if preferPort == "" {
+		card, err := a.cards.getByName(firstOutput.CardName)
+		if err != nil {
+			logger.Warning(err)
+			return firstOutput
+		}
+		// TODO: 这个逻辑有问题，下次来修改
+		for _, preferProfile := range card.Profiles {
+			if preferProfile.Available == 0 {
+				continue
+			}
+
+			for _, port := range card.Ports {
+				if port.Available != pulse.AvailableTypeNo &&
+					port.Direction == pulse.DirectionSink &&
+					port.Profiles.Exists(preferProfile.Name) {
+					return PriorityPort{
+						CardName: firstOutput.CardName,
+						PortName: port.Name,
+						PortType: GetPortType(firstOutput.CardName, port.Name),
+					}
+
+				}
+			}
+		}
+
+	}
+	if firstOutput.PortName == preferPort {
+		return firstOutput
+	}
+	// 查找PriorityManager中对应端口
+	for _, pp := range GetPriorityManager().Output.Ports {
+		if pp.PortName == preferPort {
+			return *pp
+		}
+	}
+
+	// 正常情况下，在PriorityManager是一定存在的，如果不存在，则返回firstOutput
+	logger.Warning("prefer port not found, maybe something wrong", firstOutput)
+	return firstOutput
+}
+
 func (a *Audio) refreshDefaultSinkSource() {
 	defaultSink := a.ctx.GetDefaultSink()
 	defaultSource := a.ctx.GetDefaultSource()
+	preferPort := a.tryGetPreferOutPut()
 
-	if a.defaultSink != nil && a.defaultSink.Name != defaultSink {
-		logger.Debugf("update default sink to %s", defaultSink)
-		if a.misc != 0 {
-			a.misc = 0
-			go pauseAllPlayers()
-		} else if a.defaultSink.pluggable {
-			// 异步状况下，可能整个card不存在(比如蓝牙)，可插拔sink切换, 需再判断下card信息。
-			if _, err := a.ctx.GetCard(a.defaultSink.Card); err != nil {
-				go pauseAllPlayers()
+	// pipewire设置的时候，sink会变，在refresh的时候重新设置profile的activeport
+	sinkInfo := a.getSinkInfoByName(defaultSink)
+	if sinkInfo == nil {
+		logger.Warningf("refresh defaultSink failed, defaultSink %v not found,", defaultSink)
+		return
+	}
+	logger.Debug("refreshDefaultSinkSource, defaultSink: ", sinkInfo.Index, sinkInfo.Name, a.getCardNameById(sinkInfo.Card), sinkInfo.ActivePort.Name)
+	card, err := a.cards.getByName(preferPort.CardName)
+	if err != nil || card == nil {
+		logger.Warningf("card not found %v, cards:%v", preferPort.CardName, a.cards)
+		return
+	}
+	// GetPriorityManager中的port是refresh之后的，正常情况下一定存在的
+	// pipewire sink变化的时候，可能其sink列表中不存在当前设置的端口所对应的sink，说明pipewire的切换还未完成
+	if sinkInfo.Card != card.Id || sinkInfo.ActivePort.Name != preferPort.PortName {
+		// 查找声卡所对应的sink是否存在
+		var sink *Sink = nil
+		for _, tmpSink := range a.sinks {
+			if tmpSink.Card == card.Id {
+				sink = tmpSink
+				_, found := getPortByName(tmpSink.Ports, preferPort.PortName)
+				if found {
+					sink = tmpSink
+					break
+				}
 			}
 		}
-		a.updateDefaultSink(defaultSink)
+		if sink != nil && sink.Name != defaultSink {
+			logger.Debugf("update default sink to %s with port %v", sink.Name, preferPort.PortName)
+			if a.misc != 0 {
+				a.misc = 0
+				go pauseAllPlayers()
+			} else if sink.pluggable {
+				// 异步状况下，可能整个card不存在(比如蓝牙)，可插拔sink切换, 需再判断下card信息。
+				if _, err := a.ctx.GetCard(a.defaultSink.Card); err != nil {
+					go pauseAllPlayers()
+				}
+			}
+			a.ctx.SetDefaultSink(sink.Name)
+			a.updateDefaultSink(sink.Name)
+		} else {
+			logger.Warningf("not found available sink with first port %v", preferPort.PortName)
+		}
 	} else {
 		logger.Debugf("keep default as %s", defaultSink)
 		if a.misc != 0 {
@@ -694,7 +931,9 @@ func (a *Audio) refreshDefaultSinkSource() {
 					go pauseAllPlayers()
 				} else {
 					// 非可插拔sink 和 可插拔sink的port优先级变低了才暂停。
-					if !a.defaultSink.pluggable || port.Priority < a.misc {
+					if !a.defaultSink.pluggable ||
+						port.Priority < a.misc ||
+						port.Available == pulse.AvailableTypeNo {
 						go pauseAllPlayers()
 					}
 				}
@@ -759,11 +998,6 @@ func (a *Audio) init() error {
 	// 更新本地数据
 	a.refresh()
 	a.oldCards = a.cards
-	for _, card := range a.cards {
-		if isBluezAudio(card.core.Name) {
-			card.AutoSetBluezMode()
-		}
-	}
 
 	serverInfo, err := a.ctx.GetServer()
 	if err == nil {
@@ -781,19 +1015,31 @@ func (a *Audio) init() error {
 		}
 
 		for _, source := range a.sources {
-			if source.Name == a.defaultSourceName {
+			if strings.Contains(a.defaultSourceName, "record_mono") && strings.Contains(source.Name, "alsa_input.platform-rk809-sound.analog-stereo") {
 				a.defaultSource = source
 				a.PropsMu.Lock()
 				a.setPropDefaultSource(source.getPath())
 				a.PropsMu.Unlock()
+				logger.Debug("init setPropDefaultSource:", source.Name, source.getPath())
+			} else {
+				if source.Name == a.defaultSourceName {
+					a.defaultSource = source
+					a.PropsMu.Lock()
+					a.setPropDefaultSource(source.getPath())
+					a.PropsMu.Unlock()
+				}
 			}
 		}
 		a.mu.Unlock()
 	} else {
 		logger.Warning(err)
 	}
+	if a.defaultSink != nil {
+		if err := a.defaultSink.SetMono(a.Mono); err != nil {
+			logger.Warning(err)
+		}
+	}
 
-	GetBluezAudioManager().Load()
 	GetConfigKeeper().Load()
 
 	logger.Debug("init cards")
@@ -840,7 +1086,7 @@ func (a *Audio) init() error {
 	a.moveSinkInputsToDefaultSink()
 
 	// 蓝牙支持的模式
-	a.setPropBluetoothAudioModeOpts([]string{"a2dp", "headset"})
+	a.setPropBluetoothAudioModeOpts([]string{"a2dp", "headset", "handsfree"})
 
 	return nil
 }
@@ -922,6 +1168,10 @@ func (a *Audio) findSourceByCardIndexPortName(cardId uint32, portName string) *p
 
 // set default sink and sink active port
 func (a *Audio) setDefaultSinkWithPort(cardId uint32, portName string) error {
+	if portName == dndVirtualSinkName || cardId == math.MaxUint32 {
+		a.ctx.SetDefaultSink(portName)
+		return nil
+	}
 	_, portConfig := GetConfigKeeper().GetCardAndPortConfig(a.getCardNameById(cardId), portName)
 	if !portConfig.Enabled {
 		return fmt.Errorf("card #%d port %q is disabled", cardId, portName)
@@ -984,10 +1234,15 @@ func (a *Audio) setDefaultSourceWithPort(cardId uint32, portName string) error {
 		logger.Debugf("set source #%d port %s", source.Index, portName)
 		a.ctx.SetSourcePortByIndex(source.Index, portName)
 	}
-
+	logger.Debug("a.getDefaultSourceName() ", a.getDefaultSourceName())
 	if a.getDefaultSourceName() != source.Name {
-		logger.Debugf("set default source #%d %s", source.Index, source.Name)
-		a.ctx.SetDefaultSource(source.Name)
+		if strings.Contains(source.Name, "platform-rk809-sound.analog-stereo") {
+			a.ctx.SetDefaultSource("record_mono")
+			a.updateDefaultSource(source.Name)
+			logger.Debugf("set default source %s as record_mono", source.Name)
+		} else {
+			a.ctx.SetDefaultSource(source.Name)
+		}
 	}
 
 	return nil
@@ -996,8 +1251,7 @@ func (a *Audio) setDefaultSourceWithPort(cardId uint32, portName string) error {
 // SetPort activate the port for the special card.
 // The available sinks and sources will also change with the profile changing.
 func (a *Audio) SetPort(cardId uint32, portName string, direction int32) *dbus.Error {
-	logger.Debugf("Audio.SetPort card idx: %d, port name: %q, direction: %d",
-		cardId, portName, direction)
+	logger.Infof("dbus call SetPort with cardId %d, portName %s and direction %d", cardId, portName, direction)
 
 	if !a.isPortEnabled(cardId, portName, direction) {
 		return dbusutil.ToError(fmt.Errorf("card idx: %d, port name: %q is disabled", cardId, portName))
@@ -1005,6 +1259,7 @@ func (a *Audio) SetPort(cardId uint32, portName string, direction int32) *dbus.E
 
 	err := a.setPort(cardId, portName, int(direction))
 	if err != nil {
+		logger.Warning(err)
 		return dbusutil.ToError(err)
 	}
 
@@ -1072,11 +1327,14 @@ func (a *Audio) findSources(cardId uint32, activePortName string) []*Source {
 }
 
 func (a *Audio) SetPortEnabled(cardId uint32, portName string, enabled bool) *dbus.Error {
-	if enabled {
-		logger.Debugf("enable port<%d,%s>", cardId, portName)
-	} else {
-		logger.Debugf("disable port<%d,%s>", cardId, portName)
+	logger.Infof("dbus call SetPortEnabled with cardId %d, portName %s and enabled %t", cardId, portName, enabled)
+
+	if !a.enableAutoSwitchPort {
+		err := errors.New("DConfig of org.deepin.dde.daemon.audio autoSwitchPort is false")
+		logger.Warning(err)
+		return dbusutil.ToError(err)
 	}
+
 	GetConfigKeeper().SetEnabled(a.getCardNameById(cardId), portName, enabled)
 
 	err := a.service.Emit(a, "PortEnabledChanged", cardId, portName, enabled)
@@ -1105,7 +1363,8 @@ func (a *Audio) SetPortEnabled(cardId uint32, portName string, enabled bool) *db
 
 func (a *Audio) IsPortEnabled(cardId uint32, portName string) (enabled bool, busErr *dbus.Error) {
 	// 不建议使用这个接口，可以从Cards和CardsWithoutUnavailable属性中获取此状态
-	logger.Debugf("check is port<%d,%s> enabled", cardId, portName)
+	logger.Infof("dbus call IsPortEnabled with cardId %d and portName %s", cardId, portName)
+
 	_, portConfig := GetConfigKeeper().GetCardAndPortConfig(a.getCardNameById(cardId), portName)
 	return portConfig.Enabled, nil
 }
@@ -1158,31 +1417,37 @@ func (a *Audio) setPort(cardId uint32, portName string, direction int) error {
 		return a.setDefaultSourceWithPort(cardId, portName)
 	}
 
-	// 蓝牙特殊情况下会出错，导致profile为off, 需要重新寻找合适的
-	if targetPortInfo.Profiles.Exists(card.ActiveProfile.Name) && card.ActiveProfile.Name != "off" {
-		// no need to change profile
-		return setDefaultPort()
+	if portName == dndVirtualSinkName || cardId == math.MaxUint32 {
+		a.ctx.SetDefaultSink(portName)
+		return nil
 	}
 
 	// match the common profile contain sinkPort and sourcePort
 	oppositePortInfo, _ := card.Ports.Get(oppositePort, oppositeDirection)
 	commonProfiles := getCommonProfiles(targetPortInfo, oppositePortInfo)
-	var targetProfile string
-	if len(commonProfiles) != 0 {
-		targetProfile = commonProfiles[0].Name
-	} else {
-		name, err := card.tryGetProfileByPort(portName)
-		if err != nil {
-			return err
+	var targetProfile = GetConfigKeeper().GetPortProfile(card.core.Name, portName)
+	if targetProfile == "" || !targetPortInfo.Profiles.Exists(targetProfile) {
+		if len(commonProfiles) != 0 {
+			targetProfile = commonProfiles[0].Name
+		} else {
+			name, err := card.tryGetProfileByPort(portName)
+			if err != nil {
+				return err
+			}
+			targetProfile = name
 		}
-		targetProfile = name
 	}
-	// workaround for bluetooth, set profile to 'a2dp_sink' when port direction is output
-	if direction == pulse.DirectionSink && targetPortInfo.Profiles.Exists("a2dp_sink") {
-		targetProfile = "a2dp_sink"
+
+	// 如果声卡的当前使用的配置文件对应不上，当切换配置文件时，sink会改变，则在refresh的时候设置defaultSink
+	if direction == pulse.DirectionSink {
+		GetConfigKeeper().SetProfile(card.core.Name, portName, targetProfile)
+		if card.ActiveProfile.Name != targetProfile {
+			card.core.SetProfile(targetProfile)
+			return nil
+		}
 	}
-	card.core.SetProfile(targetProfile)
-	logger.Debug("set profile", targetProfile)
+
+	// 如果是一致的
 	return setDefaultPort()
 }
 
@@ -1227,6 +1492,8 @@ func (a *Audio) resetSourceVolume() {
 }
 
 func (a *Audio) Reset() *dbus.Error {
+	logger.Infof("dbus call Reset")
+
 	a.resetSinksVolume()
 	a.resetSourceVolume()
 	gsSoundEffect := gio.NewSettings(gsSchemaSoundEffect)
@@ -1323,6 +1590,12 @@ func (a *Audio) resumeSourceConfig(s *Source, isPhyDev bool) {
 
 	s.setMute(GetConfigKeeper().Mute.MuteInput)
 
+	// 蓝牙不支持噪音抑制
+	if portConfig.ReduceNoise && isBluezAudio(s.Name) {
+		logger.Debug("bluetooth audio device cannot open reduce-noise")
+		GetConfigKeeper().SetReduceNoise(a.getCardNameById(s.Card), s.ActivePort.Name, false)
+	}
+
 	// 不要在降噪通道上重复开启降噪
 	if isPhyDev {
 		logger.Debugf("physical source, set reduce noise %v", portConfig.ReduceNoise)
@@ -1360,8 +1633,23 @@ func (a *Audio) refreshBluetoothOpts() {
 		return
 	}
 
-	a.setPropBluetoothAudioModeOpts(card.BluezModeOpts())
-	a.setPropBluetoothAudioMode(card.BluezMode())
+	// 蓝牙音频的模式应该显示为端口下的profile的列表
+	port, err := card.Ports.Get(a.defaultSink.ActivePort.Name, pulse.DirectionSink)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	var opts []string
+	for _, profile := range port.Profiles {
+		if profile.Available == 0 {
+			continue
+		}
+		opts = append(opts, profile.Name)
+	}
+	logger.Debug("refreshBluetoothOpts:", port.Name, opts)
+	a.setPropBluetoothAudioModeOpts(opts)
+	a.setPropBluetoothAudioMode(card.ActiveProfile.Name)
 }
 
 func (a *Audio) updateDefaultSink(sinkName string) {
@@ -1398,6 +1686,11 @@ func (a *Audio) updateDefaultSink(sinkName string) {
 
 	a.defaultSink = sink
 	defaultSinkPath := sink.getPath()
+	if sink != nil {
+		if err := sink.SetMono(a.Mono); err != nil {
+			logger.Warning(err)
+		}
+	}
 
 	a.resumeSinkConfig(sink)
 
@@ -1405,13 +1698,13 @@ func (a *Audio) updateDefaultSink(sinkName string) {
 	a.setPropDefaultSink(defaultSinkPath)
 	a.PropsMu.Unlock()
 
-	logger.Debug("set prop default sink:", defaultSinkPath)
+	logger.Debug("set prop default sink:", defaultSinkPath, a.defaultSink.ActivePort.Name)
 }
 
 func (a *Audio) updateSources(index uint32) (source *Source) {
 	sourceInfoList := a.ctx.GetSourceList()
 	for _, sourceInfo := range sourceInfoList {
-		//如果音频为输入，过滤到所有的monitor
+		// 如果音频为输入，过滤到所有的monitor
 		if strings.HasSuffix(sourceInfo.Name, ".monitor") {
 			logger.Debugf("skip %s source update", sourceInfo.Name)
 			continue
@@ -1463,6 +1756,14 @@ func (a *Audio) updateDefaultSource(sourceName string) {
 	}
 	logger.Debugf("updateDefaultSource #%d %s", sourceInfo.Index, sourceName)
 
+	if !isPhysicalDevice(sourceName) {
+		sourceInfo = a.getSourceInfoByName(sourceInfo.Proplist["device.master_device"])
+		if sourceInfo == nil {
+			logger.Warning("failed to get virtual device sourceInfo for name:", sourceName)
+			return
+		}
+	}
+	logger.Debug("sourceInfo", sourceInfo)
 	a.mu.Lock()
 	source, ok := a.sources[sourceInfo.Index]
 	a.mu.Unlock()
@@ -1476,6 +1777,16 @@ func (a *Audio) updateDefaultSource(sourceName string) {
 		}
 	}
 
+	if strings.Contains(source.Name, "record_mono") {
+		sourceInfo := a.getSourceInfoByName("alsa_input.platform-rk809-sound.analog-stereo")
+		if sourceInfo != nil {
+			a.mu.Lock()
+			if v, ok := a.sources[sourceInfo.Index]; ok {
+				source = v
+			}
+			a.mu.Unlock()
+		}
+	}
 	a.mu.Lock()
 	a.defaultSource = source
 	a.mu.Unlock()
@@ -1648,29 +1959,36 @@ func (a *Audio) isPortEnabled(cardId uint32, portName string, direction int32) b
 
 // 设置蓝牙模式
 func (a *Audio) SetBluetoothAudioMode(mode string) *dbus.Error {
+	logger.Infof("dbus call SetBluetoothAudioMode with mode %s", mode)
+
 	card, err := a.cards.get(a.defaultSink.Card)
 	if err != nil {
 		logger.Warning(err)
 	}
-
-	if !isBluezAudio(card.core.Name) {
-		return dbusutil.ToError(fmt.Errorf("current card %s is not bluetooth audio device", card.core.Name))
+	if card.Ports == nil {
+		return nil
+	}
+	port, err := card.Ports.Get(a.defaultSink.ActivePort.Name, pulse.DirectionSink)
+	if err != nil {
+		logger.Warning(err)
+		return dbusutil.ToError(err)
 	}
 
-	for _, profile := range card.Profiles {
-		/* 这里需要注意，profile.Available为0表示不可用，非0表示未知 */
-		logger.Debugf("check profile %s contains %s is %v && available != no is %v",
-			profile.Name, mode, strings.Contains(strings.ToLower(profile.Name), mode),
-			profile.Available != 0)
-		if strings.Contains(strings.ToLower(profile.Name), mode) &&
-			profile.Available != 0 {
+	if !isBluezAudio(card.core.Name) {
+		err = fmt.Errorf("current card %s is not bluetooth audio device", card.core.Name)
+		logger.Warning(err)
+		return dbusutil.ToError(err)
+	}
 
-			GetBluezAudioManager().SetMode(card.core.Name, mode)
+	for _, profile := range port.Profiles {
+		/* 这里需要注意，profile.Available为0表示不可用，非0表示未知 */
+		if profile.Name == mode && profile.Available != 0 {
+			GetConfigKeeper().SetProfile(card.core.Name, port.Name, mode)
 			logger.Debugf("set profile %s", profile.Name)
 			card.core.SetProfile(profile.Name)
 
-			// 手动切换蓝牙模式为headset，
-			if mode == bluezModeHeadset {
+			// 手动切换蓝牙模式为headset，Profiles是排序之后的，按照优先级先后来设置
+			if strings.Contains(strings.ToLower(mode), bluezModeHeadset) || strings.Contains(strings.ToLower(mode), bluezModeHandsfree) {
 				a.inputAutoSwitchCount = 0
 				GetPriorityManager().Input.SetTheFirstType(PortTypeBluetooth)
 			}
@@ -1681,6 +1999,23 @@ func (a *Audio) SetBluetoothAudioMode(mode string) *dbus.Error {
 	return dbusutil.ToError(fmt.Errorf("%s cannot support %s mode", card.core.Name, mode))
 }
 
+func (a *Audio) setEnableAutoSwitchPort(value bool) {
+	a.PropsMu.Lock()
+	a.enableAutoSwitchPort = value
+	a.PropsMu.Unlock()
+
+	if a.controlCenterGsSettings == nil {
+		return
+	} else if !isStringInSlice(a.controlCenterGsSettings.ListKeys(), gsKeyDeviceManager) {
+		return
+	}
+
+	if a.enableAutoSwitchPort != a.controlCenterDeviceManager.Get() {
+		a.controlCenterDeviceManager.Set(a.enableAutoSwitchPort)
+		logger.Info("setEnableAutoSwitchPort set a.enableAutoSwitchPort to a.controlCenterDeviceManager. value : ", a.enableAutoSwitchPort)
+	}
+}
+
 // 初始化 dsg 配置的属性
 func (a *Audio) initDsgProp() error {
 	systemBus, err := dbus.SystemBus()
@@ -1713,9 +2048,7 @@ func (a *Audio) initDsgProp() error {
 		logger.Warning(err)
 	} else {
 		logger.Info("auto switch port:", val)
-		a.PropsMu.Lock()
-		a.enableAutoSwitchPort = val
-		a.PropsMu.Unlock()
+		a.setEnableAutoSwitchPort(val)
 	}
 
 	var keyPausePlayer bool
@@ -1756,36 +2089,93 @@ func (a *Audio) initDsgProp() error {
 		logger.Info("port filter list", portFilterList)
 	}
 
+	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyReduceNoise).Store(&defaultReduceNoise)
+	if err != nil {
+		logger.Warning(err)
+	} else {
+		logger.Info("default reduce noise status:", defaultReduceNoise)
+	}
+
+	ret = make([]dbus.Variant, 0)
+	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyInputDefaultPriorities).Store(&ret)
+	if err != nil {
+		logger.Warning(err)
+	} else {
+		for i := range ret {
+			if v, ok := ret[i].Value().(float64); ok {
+				inputDefaultPriorities = append(inputDefaultPriorities, int(v))
+			}
+		}
+		logger.Info("input default priority list", inputDefaultPriorities)
+	}
+
+	ret = make([]dbus.Variant, 0)
+	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyOutputDefaultPriorities).Store(&ret)
+	if err != nil {
+		logger.Warning(err)
+	} else {
+		for i := range ret {
+			if v, ok := ret[i].Value().(float64); ok {
+				outputDefaultPriorities = append(outputDefaultPriorities, int(v))
+			}
+		}
+		logger.Info("output default priority list", outputDefaultPriorities)
+	}
+
+	getBluezModeDefault := func() {
+		var val string
+		err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyBluezModeDefault).Store(&val)
+		if err != nil {
+			logger.Warning(err)
+		} else {
+			if val == bluezModeA2dp || val == bluezModeHandsfree || val == bluezModeHeadset {
+				bluezModeDefault = val
+				logger.Info("bluez default mode:", bluezModeDefault)
+			}
+		}
+	}
+
+	getMonoEnabled := func() {
+		err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, dsgKeyMonoEnabled).Store(&a.Mono)
+		if err != nil {
+			logger.Warning(err)
+		}
+	}
+	getMonoEnabled()
 	// 监听dsg配置变化
 	a.systemSigLoop.AddHandler(&dbusutil.SignalRule{
 		Name: "org.desktopspec.ConfigManager.Manager.valueChanged",
 	}, func(sig *dbus.Signal) {
-		if strings.Contains(sig.Name, "org.desktopspec.ConfigManager.Manager.valueChanged") && len(sig.Body) == 1 {
+		if strings.Contains(sig.Name, "org.desktopspec.ConfigManager.Manager.valueChanged") &&
+			strings.Contains(string(sig.Path), "org_deepin_dde_daemon_audio") && len(sig.Body) >= 1 {
 			key, ok := sig.Body[0].(string)
-			if ok && key == dsgKeyAutoSwitchPort {
-				var val bool
-				err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, key).Store(&val)
-				if err != nil {
-					logger.Warning(err)
-				} else {
-					logger.Info("auto switch port:", val)
-					a.PropsMu.Lock()
-					a.enableAutoSwitchPort = val
-					a.PropsMu.Unlock()
-				}
-			}
-
-			if ok && key == dsgkeyPausePlayer {
-				var pausePlayer bool
-				err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, key).Store(&pausePlayer)
-				if err != nil {
-					logger.Warning(err)
-				} else {
-					logger.Info("pausePlayer config:", pausePlayer)
-					a.PropsMu.Lock()
-					a.PausePlayer = pausePlayer
-					a.emitPropChangedPausePlayer(pausePlayer)
-					a.PropsMu.Unlock()
+			if ok {
+				switch key {
+				case dsgKeyAutoSwitchPort:
+					var val bool
+					err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, key).Store(&val)
+					if err != nil {
+						logger.Warning(err)
+					} else {
+						logger.Info("auto switch port:", val)
+						a.setEnableAutoSwitchPort(val)
+					}
+				case dsgKeyBluezModeDefault:
+					getBluezModeDefault()
+				case dsgkeyPausePlayer:
+					var pausePlayer bool
+					err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, key).Store(&pausePlayer)
+					if err != nil {
+						logger.Warning(err)
+					} else {
+						logger.Info("pausePlayer config:", pausePlayer)
+						a.PropsMu.Lock()
+						a.PausePlayer = pausePlayer
+						a.emitPropChangedPausePlayer(pausePlayer)
+						a.PropsMu.Unlock()
+					}
+				case dsgKeyMonoEnabled:
+					getMonoEnabled()
 				}
 			}
 		}
@@ -1803,3 +2193,31 @@ func (a *Audio) canAutoSwitchPort() bool {
 
 	return a.enableAutoSwitchPort
 }
+
+func (a *Audio) SetMono(enable bool) *dbus.Error {
+	err := a.setMono(enable)
+	return dbusutil.ToError(err)
+}
+
+func (a *Audio) setMono(enable bool) error {
+	sink := a.getDefaultSink()
+	if sink != nil {
+		err := sink.SetMono(enable)
+		if err != nil {
+			logger.Warning(err)
+			return err
+		}
+	}
+
+	a.setPropMono(enable)
+	systemBus, err := dbus.SystemBus()
+	if err != nil {
+		return dbus.MakeFailedError(err)
+	}
+	systemConnObj := systemBus.Object("org.desktopspec.ConfigManager", a.configManagerPath)
+	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.setValue", 0, dsgKeyMonoEnabled, dbus.MakeVariant(enable)).Err
+	if err != nil {
+		return dbusutil.ToError(errors.New("dconfig Cannot set value " + dsgKeyMonoEnabled))
+	}
+	return nil
+}
