@@ -2,7 +2,7 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-package timedate1
+package timedated
 
 import (
 	"github.com/linuxdeepin/dde-daemon/loader"
